#
# spec file for package gstreamer-plugins-vaapi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gst_branch 1.0

Name:           gstreamer-plugins-vaapi
Version:        1.22.9
Release:        2.1
Summary:        Gstreamer VA-API plugins
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org
Source0:        %{url}/src/gstreamer-vaapi/gstreamer-vaapi-%{version}.tar.xz
# PATCH-FIX-OPENSUSE reduce-required-meson.patch alarrosa@suse.com -- build with meson 0.61
Patch0:         reduce-required-meson.patch

BuildRequires:  Mesa-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  meson >= 0.47.0
BuildRequires:  pkgconfig
BuildRequires:  vaapi-wayland-tools
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-codecparsers-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libva) >= 0.30.4
BuildRequires:  pkgconfig(libva-drm) >= 0.33.0
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(libva-wayland)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(wayland-client) >= 1.0.2
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.15
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
ExclusiveArch:  %{ix86} x86_64 aarch64

%description
gstreamer-vaapi is a collection of GStreamer plugins and helper
libraries that allow hardware accelerated video decoding through
VA-API.

%prep
%autosetup -n gstreamer-vaapi-%{version} -p1

%build
%meson \
	-Dpackage-origin='http://download.opensuse.org' \
	-Ddoc=disabled \
	-Degl=enabled \
	-Dencoders=enabled \
	-Ddrm=enabled \
	-Dglx=enabled \
	-Dwayland=enabled \
	-Dx11=enabled \
	-Dexamples=disabled \
	-Dtests=disabled \
	%{nil}
%meson_build

%install
%meson_install

%files
%license COPYING.LIB
%doc AUTHORS NEWS README
%{_libdir}/gstreamer-%{gst_branch}/libgstvaapi.so

%changelog
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + vaapidecode,vaapipostproc: Disable DMAbuf from caps negotiation
- Rebase reduce-required-meson.patch.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + vaapidecodebin: don't load vaapipostproc if not available.
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + No changes, version bump only.
- Rebase patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + No changes, version bump only.
- Rebase patch.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + vaapi: Skip plugin pc file for shared plugins
- Rebase patch with quilt.
- Drop devel sub-package added in 1.22.0, following upstream
  changes.
* Wed Mar  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in SLE 15:
  * reduce-required-meson.patch
* Wed Jan 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
- Update options passed to meson to current standard.
- Add new devel sub-package following upstream changes.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + vaapi:
  - Prefix internal USE_X11 define to fix build with mesa 22.3.0
  - libs: context: use queried value for attrib
  + gstreamer-vaapi cannot be built without X11 with recent mesa
* Thu Nov  3 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Remove unused buildrequires on yasm.
- Add explicit buildrequires on glib, gmodule and x11.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + vaapi:
  - Handle when no encoders/decoders available.
  - Crash in gst_vaapidecode_class_init() when no
    decoders/encoders available.
* Fri Sep 30 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Pass package-origin='http://download.opensuse.org' to meson.
- Drop unused ldconfig call from post(un), this is a plugin, not a
  shared library.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + aapi: Do not disable the whole vpp when some va
    operations not available
  + vaapidecode, vaapipostproc: Disable DMAbuf from caps
    negotiation
  + scrambled video with some Intel graphics cards
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.2:
  + No changes
* Fri Mar 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + No changes
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update  to version 1.20.0:
  + Development in GitLab was switched to a single git repository
    containing all the modules
  + GstPlay: new high-level playback library, replaces GstPlayer
  + WebM Alpha decoding support
  + Encoding profiles can now be tweaked with additional
    application-specified element properties
  + Compositor: multi-threaded video conversion and mixing
  + RTP header extensions: unified support in RTP depayloader and
    payloader base classes
  + SMPTE 2022-1 2-D Forward Error Correction support
  + Smart encoding (pass through) support for VP8, VP9, H.265 in
    encodebin and transcodebin
  + Runtime compatibility support for libsoup2 and libsoup3
    (libsoup3 support experimental)
  + Video decoder subframe support
  + Video decoder automatic packet-loss, data corruption, and
    keyframe request handling for RTP / WebRTC / RTSP
  + mp4 and Matroska muxers now support profile/level/resolution
    changes for H.264/H.265 input streams (i.e. codec data changing
    on the fly)
  + mp4 muxing mode that initially creates a fragmented mp4 which
    is converted to a regular mp4 on EOS
  + Audio support for the WebKit Port for Embedded (WPE) web page
    source element
  + CUDA based video color space convert and rescale elements and
    upload/download elements
  + NVIDIA memory:NVMM support for OpenGL glupload and gldownload
    elements
  + Many WebRTC improvements
  + The new VA-API plugin implementation fleshed out with more
    decoders and new postproc elements
  + AppSink API to retrieve events in addition to buffers and
    buffer lists
  + AppSrc gained more configuration options for the internal queue
    (leakiness, limits in buffers and time, getters to read current
    levels)
  + Updated Rust bindings and many new Rust plugins
  + Improved support for custom minimal GStreamer builds
  + Support build against FFmpeg 5.0
  + Linux Stateless CODEC support gained MPEG-2 and VP9
  + Windows Direct3D11/DXVA decoder gained AV1 and MPEG-2 support
  + Lots of new plugins, features, performance improvements and bug
    fixes
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + libs: video-format: Check if formats map is not NULL
  + vaapidecode: Autogenerate caps template
  + vaapipostproc: copy over metadata also when using system
    allocated buffer
* Sun Dec 19 2021 Josua Mayer <josua.m@t-online.de>
- Add aarch64 to ExclusiveArch: VAAPI is currently usable with the
  amdgpu driver on aarch64 devices with Radeon PCIe GPUs.
* Thu Sep 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Stop building doc sub-package, we will in the future use
  upstreams own standalone doc package. Following this: Drop
  gtk-doc and hotdoc BuildRequires and pass doc=disabled to meson.
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + plugins: Demote rank of vaapipostproc and vaapioverlay to match
    other filters
  + Don't use volatile to mean atomic (fixes compiler warnings with
    gcc 11)
* Wed Mar 31 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.18.4:
  + h264 encoder: append encoder exposure to aud
  + postproc: Fix a problem of propose_allocation when passthrough
  + glx: Iterate over FBConfig and select 8 bit color size
- Remove patch which is already included:
  * gst-vaapi-glx-iterate-over-FBConfig.patch
* Thu Jan 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add gst-vaapi-glx-iterate-over-FBConfig.patch: glx: Iterate over
  FBConfig and select 8 bit color size. Texture upload mechanism
  used by gstreamer-vaapi relies on 8 bpc. In latest mesa versions
  the first fbconfig might not be 8 bit, so iterate over it to find
  the correct config with supported values. This also adds 8 bit
  alpha size to the framebuffer configuration which is required to
  get it working properly.
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + No changes
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + H265 decoder: Fix a typo in scc reference setting.
* Wed Oct 28 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.1:
  + Highlighted bugfixes in 1.18.1
  - important security fixes
  - bug fixes and memory leak fixes
  - various stability and reliability improvements
  + gstreamer-vaapi changes:
  - decoder: don't reply src caps query with allowed if pad is
    fixed
  - plugins: decode: fix a DMA caps typo in
    ensure_allowed_srcpad_caps
* Fri Sep 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.0:
  + Highlights:
  - GstTranscoder: new high level API for applications to
    transcode media files from one format to another
  - High Dynamic Range (HDR) video information representation
    and signalling enhancements
  - Instant playback rate change support
  - Active Format Description (AFD) and Bar Data support
  - RTSP server and client implementations gained ONVIF trick
    modes support
  - Hardware-accelerated video decoding on Windows via
    DXVA2/Direct3D11
  - Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows
  - qmlgloverlay: New overlay element that renders a QtQuick
    scene over the top of an input video stream
  - imagesequencesrc: New element to easily create a video
    stream from a sequence of jpeg or png images
  - dashsink: New sink to produce DASH content
  - dvbsubenc: New DVB Subtitle encoder element
  - MPEG-TS muxing now also supports TV broadcast compliant
    muxing with constant bitrate muxing and SCTE-35 support
  - rtmp2: New RTMP client source and sink element from-scratch
    implementation
  - svthevcenc: New SVT-HEVC-based H.265 video encoder
  - vaapioverlay: New compositor element using VA-API
  - rtpmanager gained support for Google's Transport-Wide
    Congestion Control (twcc) RTP extension
  - splitmuxsink and splitmuxsrc gained support for auxiliary
    video streams
  - webrtcbin now contains some initial support for
    renegotiation involving stream addition and removal
  - RTP support was enhanced with new RTP source and sink
    elements to easily set up RTP streaming via rtp:// URIs
  - avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications
  - Support for the Video Services Forum's Reliable Internet
    Stream Transport (RIST) TR-06-1 Simple Profile
  - Universal Windows Platform (UWP) support
  - rpicamsrc: New element for capturing from the Raspberry Pi
    camera
  - RTSP Server TCP interleaved backpressure handling
    improvements as well as support for Scale/Speed headers
  - GStreamer Editing Services gained support for nested
    timelines, per-clip speed rate control and the OpenTimelineIO
    format.
  - Autotools build system has been removed in favour of Meson
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + meson build: halt configuration if no renderer API
  + libs: decoder: h265: skip all pictures prior the first I-frame
  + libs: window: x11: Avoid usage of deprecated API
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + See main gstreamer package for changelog.
- Drop upstream fixed patches:
  + gst-vaapi-fix-garbled-screen-totem.patch.
  + gst-vaapi-remove-gallium-from-white-list.patch.
* Sat Sep  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gst-vaapi-remove-gallium-from-white-list.patch: pluginutil:
  Remove Mesa from drivers white list. The Mesa Gallium driver is
  poorly tested currently, leading to bad user experience for AMD
  users. The driver can be added back to the white list at runtime
  using the GST_VAAPI_ALL_DRIVERS environment variable.
* Thu Jun 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gst-vaapi-fix-garbled-screen-totem.patch: Fix garbled video
  in totem.
- Add missing pkgconfig(wayland-protocols) BuildRequires for
  wayland support.
- Drop conditionals for no longer supported versions of openSUSE.
* Wed Jun 19 2019 mgorse@suse.com
- Update to version 1.16.0:
  + Highlights
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support, as
    well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin (msdk):
    dmabuf import/export for zero-copy integration with other
    components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element that
    allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements
- Add support for meson, but disable for now, since plugin docs
  are not built.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + Thread-safety and memory leak fixes.
  + Improve caps negotiation if downstream takes ANY caps.
  + Fix build with -DG_DISABLE_ASSERT.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.14.4:
  + Bugfix release, please see .changes in gstreamer main package.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + Bugfix release, please see .changes in gstreamer main package.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + Update docs.
  + vaapibufferpool: declare parameter display as object.
  + vaapiencode:
  - h264: set best profile in the intersected caps.
  - h264: log output caps.
  - h264: find profile in available and allowed caps.
  + plugins:
  - verify EGL display is not NULL.
  - guard GstGL code.
  - handle EGL when creating VAAPI display from gl.
  + libs:
  - display: resurrect parent private memember.
  - display: egl: initialize params structure.
  - encoder: h265: increase log2_max_pic_order_cnt range
    according to spec.
  + display: egl: fix to create VaapiDisplayEGL with native EGL
    display.
* Sat Jun 23 2018 bjorn.lie@gmail.com
- Conditionalize wayland support for openSUSE Leap 15 and newer,
  fix build for SLE 12.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
- Drop gst-vaapi-egl-mark-context-wrapped.patch and
  gst-vaapi-wayland-dont-poll-no-pending-frames.patch: Fixed
  upstream.
* Wed May  9 2018 bjorn.lie@gmail.com
- Drop gst-vaapi-add-zero-as-valid-value.patch for gst-1.14 branch.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
* Mon May  7 2018 bjorn.lie@gmail.com
- Add gst-vaapi-add-zero-as-valid-value.patch: libs: encoder: add
  zero as valid value for periodic keyframe. Enabled zero as valid
  value for keyframe-period property (bgo#793829).
* Wed May  2 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches:
  + gst-vaapi-egl-mark-context-wrapped.patch: libs: egl: utils:
    mark context as wrapped when it is. The returning egl context
    may be null, so we should check the return value (bgo#795391).
  + gst-vaapi-wayland-dont-poll-no-pending-frames.patch: wayland:
    don't poll if there are no pending frames. Otherwise the
    following poll may not return for an arbitrary amount of time.
    This can happen if another wayland event queue has flushed and
    read our events (bgo#795224).
* Thu Mar 29 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: bgo#793836, bgo#789476.
- Drop upstream fixed patches:
  + gst-vaapi-add-NULL-sentinel-to-kernel_names.patch.
  + gst-vaapi-h264-ensure-num_ref_frames-greater-0.patch.
  + gst-vaapi-plugins-handle-vaapi-allocator.patch.
  + gst-vaapi-vaapipostproc-lock-ensure_filter.patch.
  + gst-vaapi-vaapipostproc-set-discont-flag.patch.
  + gst-vaapi-vaapivideobufferpool-fix-regression.patch.
  + gst-vaapi-vaapivideomemory-remove-unused-macro.patch.
* Wed Mar 21 2018 bjorn.lie@gmail.com
- Add gst-vaapi-h264-ensure-num_ref_frames-greater-0.patch: libs:
  decoder: h264: ensure num_ref_frames is greater than 0. Even if
  it is the h264parse fault or bad video file, vaapih264dec should
  set a proper value for
  VAPictureParameterBufferH264.num_ref_frames as the driver might
  use it (bgo#793836).
* Mon Mar  5 2018 bjorn.lie@gmail.com
- Add gst-vaapi-vaapivideobufferpool-fix-regression.patch:
  vaapivideobufferpool: fix regression. The allocator in the config
  may be not VAAPI (videotestsrc, for example) and it will not have
  a video info configuration (bgo#789476).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner.
* Thu Feb 22 2018 bjorn.lie@gmail.com
- Add gst-vaapi-vaapipostproc-set-discont-flag.patch:
  vaapipostproc: set discont flag at vpp deinterlacing. When
  deinterlacing with VPP the discont flag was not forwarded to the
  new created buffer. This patch sets the discont flag if input
  buffer has it.
* Mon Feb 12 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches:
  + gst-vaapi-vaapipostproc-lock-ensure_filter.patch.
  + gst-vaapi-add-NULL-sentinel-to-kernel_names.patch.
  + gst-vaapi-vaapivideomemory-remove-unused-macro.patch.
  + gst-vaapi-plugins-handle-vaapi-allocator.patch.
- Drop non built devel subpackage, and do a minor spec clean.
- Drop no longer needed obsoletes, no current version of openSUSE
  have ever had them, do minor spec cleanup, use autosetup macro.
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + Bugs fixed: bgo#784398, bgo#786173, bgo#787818.
- Drop gst-vaapi-version-fix.patch: Fixed upstream, following this:
  drop libtool BuildRequires and no longer pass autogen.sh, and
  drop sed hack, no longer needed.
* Fri Dec  1 2017 zaitor@opensuse.org
- Add sed hack to lower needed version of autotools to that we have
  in Leap 42.x.
* Thu Nov 16 2017 zaitor@opensuse.org
- Add gst-vaapi-version-fix.patch: Fix build with new libva 2.0
  version (bgo#784398, bgo#786173, bgo#787818).
- Following the above, add libtool BuildRequires and pass
  autogen.sh before configure, as the patch touches buildsystem.
- Further drop pkgconfig(libva-egl) and pkgconfig(libva-tpi)
  BuildRequires: No longer available.
- Also drop obsolete --disable-builtin-libvpx configure call.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + Bugs fixed: bgo#754885, bgo#785032, bgo#786307, bgo#787733.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + Bugs fixed: bgo#784320.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + Bugs fixed: bgo#781759, bgo#782542, bgo#782543, bgo#783726.
* Tue May  9 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + Bugs fixed: bgo#782063, bgo#781866.
- Changes from version 1.11.91:
  + Bugs fixed: bgo#773689, bgo#774029, bgo#775848, bgo#780442,
    bgo#781142, bgo#781573, bgo#781577, bgo#781695, bgo#781759.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#771291, bgo#772838, bgo#778676, bgo#778750,
    bgo#778781, bgo#779120, bgo#779400, bgo#780302, bgo#780620.
* Wed Apr 26 2017 dimstar@opensuse.org
- Drop vaapi-tools BuildRequires: no longer needed.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Bugs fixed: bgo#749950, bgo#754680, bgo#777409, bgo#778250,
    bgo#778318, bgo#778576, bgo#778782.
- Add explicit pkgconfig(gstreamer-codecparsers-1.0) BuildRequires
  and version it: align with what configure checks for.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#753591, bgo#768266, bgo#769266, bgo#772151,
    bgo#773323, bgo#773546, bgo#773593, bgo#773939, bgo#773948,
    bgo#774030, bgo#774213, bgo#774782, bgo#775040, bgo#775041,
    bgo#775203, bgo#776084, bgo#776175, bgo#776303, bgo#777115.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Bugs fixed: bgo#777506, bgo#778010.
- Drop gstreamer-plugins-vaapi-vaapipostproc-set-GST_VAAPI.patch
  and gstreamer-plugins-vaapi-h264-reduce-frame-gaps.patch: Fixed
  upstream.
* Thu Feb  9 2017 zaitor@opensuse.org
- Add gstreamer-plugins-vaapi-vaapipostproc-set-GST_VAAPI.patch and
  gstreamer-plugins-vaapi-h264-reduce-frame-gaps.patch: Add two
  upstream bugfix commits (bgo#777506).
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + Bugs fixed: bgo#775204, bgo#774254, bgo#777146, bgo#777395,
    bgo#777395.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Bugs fixed: bgo#772838.
- Drop gstreamer-plugins-vaapi-va_wayland.patch: Fixed upstream.
- Following the above, drop libtool BuildRequires and stop passing
  autoreconf. We no longer carry any patches.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Minor bug fixes.
* Wed Nov  2 2016 zaitor@opensuse.org
- Update to version 1.10.0:
  + All the decoders have been split, one plugin feature per codec.
    So far, the available ones, depending on the driver, are:
    vaapimpeg2dec, vaapih264dec, vaapih265dec, vaapivc1dec,
    vaapivp8dec, vaapivp9dec and vaapijpegdec (which already was
    split).
  + Improvements when mapping VA surfaces into memory. It now
    differentiates between negotiation caps and allocations caps,
    since the allocation memory for surfaces may be bigger than one
    that is going to be mapped.
  + Vaapih265enc now supports constant bitrate mode (CBR).
  + Since several VA drivers are unmaintained, we decide to keep a
    whitelist with the va drivers we actually test, which is mostly
    the i915 and to a lesser degree gallium from the mesa project.
  + Exporting the environment variable GST_VAAPI_ALL_DRIVERS disables
    the whitelist.
  + Plugin features are registered at run-time, according to their
    support by the loaded VA driver. So only the decoders and
    encoder supported by the system are registered. Since the
    driver can change, some dependencies are tracked to invalidate
    the GStreamer registry and reload the plugin.
  + Dmabuf importation from upstream has been improved, gaining
    performance.
  + Vaapipostproc now can negotiate buffer transformations via
    caps.
  + Decoders now can do I-frame only reverse playback. This decodes
    I-frames only because the surface pool is smaller than the
    required by the GOP to show all the frames.
  + The upload of frames onto native GL textures has been optimized
    too, keeping a cache of the internal structures for the offered
    textures by the sink.
  + Bugs fixed: bgo#754680, bgo#772554, bgo#772599, bgo#773497,
    bgo#773589.
- Stop passing --enable-opengl to configure: No longer recognized
  nor needed.
- Pass --disable-builtin-libvpx to configure: Ensure we are using
  system provided libvpx.
- Drop libva-devel BuildRequires, and instead add vaapi-tools,
  vaapi-wayland-tools, pkgconfig(libva), pkgconfig(libva-drm),
  pkgconfig(libva-glx), pkgconfig(libva-tpi),
  pkgconfig(wayland-cursor), pkgconfig(wayland-egl),
  pkgconfig(wayland-scanner), pkgconfig(wayland-server) following
  what configure really looks for.
- Add gstreamer-plugins-vaapi-va_wayland.patch: Correctly locate
  libva-wayland headers (bgo#773946).
- All call to autoreconf, as above patch touches the build system.
* Mon Aug 22 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Bugs fixed: bgo#769250, bgo#768458, bgo#769237, bgo#768458,
    bgo#768544, bgo#767946, bgo#767934, bgo#767699, bgo#766184,
    bgo#765368.
* Tue Jun 14 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + bgo#765702: build: errors when compiling without X11.
* Sat May 28 2016 zaitor@opensuse.org
- Add pkgconfig(libva-drm), pkgconfig(libva-egl) and
  pkgconfig(libva-wayland): Ensure that all the libva-subpackages
  are available during build.
* Wed Apr 20 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#764231 : Bad call to
    gst_buffer_add_video_gl_texture_upload_meta() in
    gstvaapivideometa_texture.c.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Update Url and Source to new home at freedesktop.org.
- Pass --enable-egl, --enable-encoders, --enable-drm,
  - -enable-opengl, --enable-wayland and --enable-x11 to configure
  to ensure we build support for them.
- Bump soname following upstream changes.
- Add Mesa-libGLESv3-devel, pkgconfig(gl), pkgconfig(libdrm),
  pkgconfig(libudev), pkgconfig(libva), pkgconfig(libva-x11),
  pkgconfig(vpx) BuildRequires: New explicit dependencies.
- Drop libgstcodecparsers_vpx0, libgstvaapi-1_6-1, libgstvaapi-drm,
  libgstvaapi-egl, libgstvaapi-glx, libgstvaapi-wayland and
  libgstvaapi-x11 sub-packages and obsolete them.
- Add new doc sub-package.
* Thu Dec 24 2015 zaitor@opensuse.org
- Update to version 0.7.0:
  + Add VP9 Decoder.
  + Improvements to HEVC(H265) decoder:
  - Fix the decoding of dependent slice segment.
  - Fix decoding of stream when it has temporal sublayers.
  - Added Workaround to recognize wrongly encoded main profile
    streams.
  - Add SEI Header parsing.
  - Fix the value assigning for delta_chroma_log2_weight_denom.
  - Fix default value assignment of pred_weight_table.
  - Fix ChromaOffsetL0/ChromaOffsetL1 calculation.
  - Add calculation of WpOffsetHalfRangeC.
  - Fix the scaling list scan order.
  - Fix the picture addition in dpb() based on spec H265 v3.
  - Fix the dpb_add() based on C.5.2.3.
  - Fix flushing of dpb for EOS/EOB nal.
  + Added infrastructure for handling corrupted pictures in h264
    decoder (bgo#703921, bgo#751434).
  + Add number of fixes and optimizations to GstContext sharing
    (bgo#757598).
  + Add API for dynamic detection of OpenGL API in use
    (bgo#753099).
  + Make vaapidecode + glimagesink combination work with opengl3
    (bgo#753099).
  + Fix segfault in vaapipostproc (bgo#752558).
  + Fix seeking while using GLTextureUpload for rendering
    (bgo#752929).
  + Ported JPEG decoder to new API/ABI changes in codecparser.
  + Removed gstvaapiuploader (bgo#752777).
  + Fix 0/1 frame-rate handling in encoder (bgo#744042).
  + Validate chroma sampling according to the VA's RT format in
    Encoder (bgo#744042).
  + Number of improvements in vaapi video memory handling
    (bgo#744042).
  + Stabilization of vaapidecodebin (bgo#749554, bgo#757957).
  + Wayland fixes: Don't return GST_FLOW_ERROR on flushing
    (bgo#753598).
  + Add yasm as build dependency.
  + Remvoved custom(non-official) debian parallel compilation
    option.
  + Fix multi-resolution video handling in vaapidecode
    (bgo#753914).
  + Adding stereoscopic/multiview upstream API support
    (bgo#750835).
  + Fixed fps calculation for for forced latency framerate
    (bgo#755040).
  + Fix build issues while disabling built-in codecparsers
    (bgo#754845).
  + Mark support for GStreamer 1.2 as obsolete.
  + Update libvpx submodule to 1.4.0.
  + Fix caps negotiation for meta:GstVideoGLTextureUploadMeta
    (bgo#756686).
  + Fixed leaked display instance in vaapidecodebin (bgo#757595).
* Tue Oct 27 2015 zaitor@opensuse.org
- Stop using wayland bcond, it does not work out for us.
- Add new %%define gst_so and %%define gst_ver and use suse_version
  to decide the value of these. Allowing package to be built with
  the different branches of gstreamer existing in older versions of
  openSUSE.
- Following this, subpackages get new name depending on what
  gst-branch they are built against.
* Tue Oct 20 2015 zaitor@opensuse.org
- Update to version 0.6.1:
  + Fix a possible segmentation fault using gstreamer 1.4
    (bgo#752558).
  + Don't loose the GLTextureUpload meta on seek (bgo#752929).
  + Remove in debian rules the option --with-gstreamer-api
    (bgo#753618).
  + Add in debian rules yasm as dependency.
  + Keep a copy of input codec state (bgo#753914).
  + Renegotiate if the input caps are not equal (bgo#750835).
  + Fix the FPS denominator and numerator (bgo#755040).
  + Initialize H264 PPS's slice_group_id (bgo#754845).
  + Verify for H264 MVC and H265 SPS when running configure
    (bgo#754845).
  + Link libgstvaapi_parse.so against libgstcodecparsers.so.
- Stop passing --with-gstreamer-api=1.0 to configure, no longer
  recognized.
* Mon Jul 20 2015 zaitor@opensuse.org
- Correct %%bconds, fixes build on SLE12 and openSUSE42 where we do
  not have wayland.
- Clean up spec.
- Update URL to new home.
* Fri Jul 17 2015 zaitor@opensuse.org
- Update to version 0.6.0:
  + Major changes:
  - Add HEVC(H265) Decoder.
  - Add HEVC(H265) Encoder.
  - Add VP8 Encoder.
  - Add JPEG Encoder.
  - Add a vaapidecodebin(vaapidecode->queue->vaapipostproc)
    element.
  - Add support for EGL.
  - Add Skin-Tone-Enhancement feature in vaapipostproc.
  - Add support for H.264 Multiview High profile encoding with
    more than 2 views.
  + Other Changes of interest:
  - Add support for loss of pictures in h264 decoder.
  - Add support for GstVideoGLTextureOrientation in plugins.
  - Add support for BGRA textures in plugins.
  - Add a simple-encoder test program that uses libgstvaapi for
    video encoding to elementary streams.
  - Add finer wayland frame control and many other optimizations.
  - Add packed SEI header message support in h264 encoder for CBR
    mode.
  - Add scaling of quality factor and Quantization tables for
    JPEG encoder.
  - Add GstColorBalance interface in vaapipostproc.
  - Add a handoff signal to vaapisink.
  - Add rounding control handling for VC1 simple and Main
    profile.
  - Record glconext supplied by downstream to enable run-time
    compatibility check.
  - Switch back to single thread implementation in vaapidecode.
  - Set decoding latency in vaapidecode by assuming realtime
    performance for the HW decoding.
  - Allow vaapidecode to connect with glimagesink, mark x11
    display as compatible with EGL.
  - Allow decoding of VC1 streams which contain user BDUs.
  - Use git.mk, a small Makefile to autogenerate .gitignore
    files.
  - Expose the overlay capability in vaapisink for compatibility
    with dvbsuboverlay.
  - Expose deinterlace property to vaapidecodebin.
  - Enable VPP element in vaapidecodebin only if there is HW
    support.
  - Fix autoplugging of vaapidecode in playbin for wmv/asf
    streams.
  - Fix multi-slice hevc encoding.
  - Fix ABBA deadlock between vaapisink and vaapipostproc if
    running in different threads.
  - Fix Seeking failure while using navseek in pipeline.
  - Fix PTS cache for MPEG2 GOP start.
  - Fix the wrong selection of passthrough mode in vaapipostproc.
  - Fix GstVaapiVideoPool related dead-lock.
  - Fix the race condition while setting drm device type.
  - Fix crash in vaapidecode if buffer outlives the decoder.
  - Fix memory leak in vaapidecode.
  - Fix multiple caps negotiation issues with vaapi elements.
  - Improve check for upstream element that requires DMABUF
    buffer pool.
  - Fix vaapisink memory leak in debug mode.
  - Fix crash when seeking mpeg2 strems.
  - Fix support for Wayland/EGL running alongside X11 (around 70+
    bug reports fixed).
  + GStreamer support corner:
  - Removed the support for GStreamer 0.10 and 1.0
  - GStreamer >= 1.2 is the minimal requirement
  - GStreamer 1.2.x is deprecated, and will be obsoleted in a
    future release
- Add a define soname and set it to 2, following upstream changes.
  Rename all sub-packages to get the new soname.
* Sun Mar 29 2015 zaitor@opensuse.org
- Update to version 0.5.10:
  + Add support for DRM Render-Nodes for headless operation.
  + Add support for VA surface buffer sharing with DMABUF and GEM
    handles.
  + Add support for v4l2src with io-mode={dmabuf,dmabuf-import}.
  + Drop support for VA/GLX specific APIs in libgstvaapi and
    vaapisink (bgo#736711).
  + Improvements to H.264 codecs:
  - Fix profile limits for encoding.
  - Fix pixel-aspect-ratio in the encoded stream.
  - Add decoding support for interlaced streams with
    repeat-first-field (RFF).
  - Fix decoding of interlaced streams in top-field-first order
    (TFF) (bgo#739291).
  - Fix decoding of UK DVB-T2 streams (bgo#739291).
  + Improvements to plugin elements:
  - Add support for dma_buf imports (Wind Yuan) (bgo#735362).
  - Allow for SW decoding fallbacks with unsupported profiles
    (bgo#730997).
  - Make vaapipostproc work with SW elements (bgo#720174,
    bgo#704078).
  - Allow vaapipostproc to integrate with GL downstream elements
    (bgo#735231).
  - Add support for high-quality scaling to vaapipostproc
    ("scale-method=hq").
  - Fix advanced deinterlacing when it is the unique filter
    applied.
  - Add GstColorBalance interface to vaapisink (bgo#722390).
  - Implement the GstNavigation interface into vaapisink
    (bgo#711479).
  - Allow rescaling of X11 window for vaapisink (bgo#711478).
  - Optimizations to vaapidecode thread handling (bgo#734616).
  - Fix deinterlacing from non VA memory buffers (bgo#726270).
  - Fix clearing of subtitle overlay.
  - Fix clearing of vaapipostproc state during restart.
- Bump soname following upstream changes.
* Sat Dec 13 2014 zaitor@opensuse.org
- Add pkgconfig(xrender) and pkgconfig(xrandr) BuildRequires: They
  were missing from the inital build.
* Tue Dec  9 2014 zaitor@opensuse.org
- Initial packaging.
